@@ -4,6 +4,21 @@ calculator = Riposte(prompt="▲:~$ ")
 
 MEMORY = []
 
+def main():
+    print(
+        """
+     ________  ________  ________   ___      ___ ___    ___ 
+    |\   ____\|\   __  \|\   ___  \|\  \    /  /|\  \  /  /|
+    \ \  \___|\ \  \|\  \ \  \\\\ \  \ \  \  /  / | \  \/  / /
+     \ \  \    \ \  \\\\\  \ \  \\\\ \  \ \  \/  / / \ \    / / 
+      \ \  \____\ \  \\\\\  \ \  \\\\ \  \ \    / /   /     \/  
+       \ \_______\ \_______\ \__\\\\ \__\ \__/ /   /  /\   \  
+        \|_______|\|_______|\|__| \|__|\|__|/   /__/ /\ __\ 
+                                                |__|/ \|__| 
+                                                            
+    """
+    )
+    calculator.run()
 
 @calculator.command("dtb")
 def decimalToBinary(x: int):
@@ -220,17 +235,5 @@ def close():
 
 
 if __name__ == "__main__":
-    print(
-        """
-     ________  ________  ________   ___      ___ ___    ___ 
-    |\   ____\|\   __  \|\   ___  \|\  \    /  /|\  \  /  /|
-    \ \  \___|\ \  \|\  \ \  \\\\ \  \ \  \  /  / | \  \/  / /
-     \ \  \    \ \  \\\\\  \ \  \\\\ \  \ \  \/  / / \ \    / / 
-      \ \  \____\ \  \\\\\  \ \  \\\\ \  \ \    / /   /     \/  
-       \ \_______\ \_______\ \__\\\\ \__\ \__/ /   /  /\   \  
-        \|_______|\|_______|\|__| \|__|\|__|/   /__/ /\ __\ 
-                                                |__|/ \|__| 
-                                                            
-    """
-    )
-    calculator.run()
+    main()
+
